(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     27119,        773]
NotebookOptionsPosition[     24298,        720]
NotebookOutlinePosition[     24706,        736]
CellTagsIndexPosition[     24663,        733]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Three-Body Phase Spaces", "Title",
 CellChangeTimes->{{3.826770487193734*^9, 3.8267704984263897`*^9}, {
  3.932364342301263*^9, 
  3.932364343116723*^9}},ExpressionUUID->"bd5a5d2d-a113-4a65-94cb-\
ebcdc73c1261"],

Cell[CellGroupData[{

Cell["Calculation of a Three-Body Decay following the PDG", "Chapter",
 CellChangeTimes->{{3.826770458711645*^9, 3.826770502094529*^9}, {
  3.93236434649658*^9, 
  3.932364346978115*^9}},ExpressionUUID->"7463759e-6cfd-4cec-a3df-\
d3ec877f98fc"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
    "We", " ", "want", " ", "to", " ", "\"\<prove\>\"", " ", "some", " ", 
     "of", " ", "the", " ", "formulae", " ", "for", " ", "a", " ", "three"}], 
    "-", 
    RowBox[{
    "body", " ", "decay", " ", "given", " ", "in", " ", "the", " ", "PDG"}]}],
    ",", " ", 
   RowBox[{
    RowBox[{"<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"pdg", ".", "lbl", ".", "gov"}], "/", "2019"}], "/", 
        "reviews"}], "/", "rpp2018"}], "-", "rev", "-", 
      RowBox[{"kinematics", ".", "pdf"}]}], ">"}]}], ",", " ", 
   RowBox[{
   "see", " ", "also", " ", "the", " ", "corresponding", " ", "handwritten", 
    " ", 
    RowBox[{"notes", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.826770504326002*^9, 3.826770542909724*^9}, {
  3.82677606000465*^9, 
  3.826776071676485*^9}},ExpressionUUID->"5c65b39f-f0a1-4376-8d8a-\
b8f9e3a6d008"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Kallen", " ", 
    RowBox[{"function", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Lambda]", "[", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
    RowBox[{
     SuperscriptBox["x", "2"], "+", 
     SuperscriptBox["y", "2"], "+", 
     SuperscriptBox["z", "2"], "-", 
     RowBox[{"2", "x", " ", "y"}], "-", 
     RowBox[{"2", "x", " ", "z"}], "-", 
     RowBox[{"2", "y", " ", "z"}]}]}], ";"}]}]], "Input",ExpressionUUID->\
"477d2a7a-0748-4af5-ac5c-8e442e5236c3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Momenta", " ", "in", " ", "the", " ", "CMS", " ", "of", " ", "particles", 
    " ", 
    RowBox[{"(", 
     RowBox[{"1", ",", "2"}], ")"}], " ", "and", " ", "in", " ", "the", " ", 
    "rest", " ", "frame", " ", "of", " ", "the", " ", "decaying", " ", 
    RowBox[{"particle", "."}]}], "  ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["m1", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["m2", "2"]}]]}], "\[Equal]", 
      SqrtBox["s"]}], ",", "p"}], "]"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["m3", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", "s"}]]}], "\[Equal]", "M"}], ",", 
     "p"}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.826770566255166*^9, 3.8267705789243517`*^9}, {
  3.826770768943754*^9, 3.826770817555573*^9}, {3.82677657179272*^9, 
  3.826776574662187*^9}, {3.826776649060688*^9, 
  3.826776664420471*^9}},ExpressionUUID->"a9b822e3-fb48-4c33-ac94-\
5ecb0ea797e7"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["m1", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m1", "2"], " ", 
           SuperscriptBox["m2", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m1", "2"], " ", "s"}], "+", 
          SuperscriptBox["m2", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m2", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", 
         SqrtBox["s"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["m1", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["m1", "2"], " ", 
          SuperscriptBox["m2", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["m1", "2"], " ", "s"}], "+", 
         SuperscriptBox["m2", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["m2", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.826771401869486*^9},
 CellLabel->
  "Out[129]=",ExpressionUUID->"0b17044b-088c-4bdb-98c5-a090cb5d55a5"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["M", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox["m3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M", "2"], " ", "s"}], "+", 
          SuperscriptBox["m3", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m3", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", "M"}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["M", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox["m3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M", "2"], " ", "s"}], "+", 
         SuperscriptBox["m3", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["m3", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", "M"}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",\

 CellChangeTimes->{3.8267714019257727`*^9},
 CellLabel->
  "Out[130]=",ExpressionUUID->"89c0858b-f308-43ac-9627-cea5b0578a45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "momenta", " ", "and", " ", "energies", " ", "found", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", " ", 
   RowBox[{
   "Particle", " ", "1", " ", "in", " ", "the", " ", "CMS", " ", "of", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", ",", "2"}], ")"}], "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"p1", "=", 
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["m1", "2"], ",", 
         SuperscriptBox["m2", "2"]}], "]"}]], 
      RowBox[{"2", 
       SqrtBox["s"]}]], "//", "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"E1", "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["m1", "2"]}]], "//", "Simplify"}], "//", 
     "PowerExpand"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Particle", " ", "3", " ", "in", " ", "the", " ", "rest", " ", "frame", 
     " ", "of", " ", "the", " ", "decaying", " ", 
     RowBox[{"particle", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"p3", "=", 
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["M", "2"], ",", 
         SuperscriptBox["m3", "2"]}], "]"}]], 
      RowBox[{"2", "M"}]], "//", "Simplify"}]}], "\[IndentingNewLine]", 
   RowBox[{"E3", "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["p3", "2"], "+", 
        SuperscriptBox["m3", "2"]}]], "//", "Simplify"}], "//", 
     "PowerExpand"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
     RowBox[{"Note", " ", "that", " ", "here"}], ",", " ", 
     RowBox[{
     "the", " ", "correct", " ", "solution", " ", "for", " ", "the", " ", 
      "energies", " ", "can", " ", "be", " ", "obtained", " ", "by", " ", 
      "simply", " ", "using", " ", "the", " ", "function", " ", 
      "\"\<PowerExpand\>\"", " ", "after", " ", "taking", " ", "the", " ", 
      "square", " ", 
      RowBox[{"root", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Particle", " ", "2", " ", "in", " ", "the", " ", "CMS", " ", "of", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"1", ",", "2"}], ")"}], "."}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"E2", "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["p1", "2"], "+", 
        SuperscriptBox["m2", "2"]}]], "//", "Simplify"}], "//", 
     "PowerExpand"}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{"Particle", " ", 
     RowBox[{"(", 
      RowBox[{"1", ",", "2"}], ")"}], " ", "in", " ", "the", " ", "rest", " ",
      "frame", " ", "of", " ", "the", " ", "decaying", " ", 
     RowBox[{"particle", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{"E12", "=", 
    RowBox[{
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox["p3", "2"], "+", "s"}]], "//", "Simplify"}], "//", 
     "PowerExpand"}]}]}]}]], "Input",
 CellChangeTimes->{{3.826770638200732*^9, 3.826770664454094*^9}, {
   3.8267708162119913`*^9, 3.8267708964653063`*^9}, {3.826771314038703*^9, 
   3.826771321135222*^9}, {3.826771481671167*^9, 3.826771561540495*^9}, {
   3.826771593421763*^9, 3.826771679710774*^9}, {3.826771733620549*^9, 
   3.826771740865314*^9}, {3.8267728190917883`*^9, 3.826772834404399*^9}, {
   3.8267730481464252`*^9, 3.826773249692938*^9}, {3.8267765668523283`*^9, 
   3.82677657037383*^9}, 
   3.82678657768023*^9},ExpressionUUID->"c6a2b496-d952-4f3f-bb15-\
1ec509a75202"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox["m1", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["m1", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m2", "2"], "+", "s"}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m2", "2"], "-", "s"}], ")"}], "2"]}]], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.826773197678897*^9}},
 CellLabel->
  "Out[253]=",ExpressionUUID->"a965b5e6-838b-4b63-8d2c-db41302dbda3"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["m1", "2"], "-", 
    SuperscriptBox["m2", "2"], "+", "s"}], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.8267731976828327`*^9}},
 CellLabel->
  "Out[254]=",ExpressionUUID->"cb2277a8-fb99-4af2-a625-a330cbe164ea"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox["M", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m3", "2"], "+", "s"}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m3", "2"], "-", "s"}], ")"}], "2"]}]], 
   RowBox[{"2", " ", "M"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.826773197686458*^9}},
 CellLabel->
  "Out[255]=",ExpressionUUID->"c697b383-8e66-4030-82d4-534fd1608fcb"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["M", "2"], "+", 
    SuperscriptBox["m3", "2"], "-", "s"}], 
   RowBox[{"2", " ", "M"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.826773197689839*^9}},
 CellLabel->
  "Out[256]=",ExpressionUUID->"2649d20e-9e19-4d42-b4ac-510e626f3470"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{"-", 
     SuperscriptBox["m1", "2"]}], "+", 
    SuperscriptBox["m2", "2"], "+", "s"}], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.826773197692923*^9}},
 CellLabel->
  "Out[257]=",ExpressionUUID->"553f010c-8e7b-4278-a743-a5931a1e34eb"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["M", "2"], "-", 
    SuperscriptBox["m3", "2"], "+", "s"}], 
   RowBox[{"2", " ", "M"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826770651709742*^9, 3.8267706654533587`*^9}, 
   3.826770896766336*^9, 3.8267713214921227`*^9, 3.826771482361294*^9, {
   3.826771551468349*^9, 3.826771562039412*^9}, {3.826771643678924*^9, 
   3.826771646528749*^9}, 3.8267716800097523`*^9, {3.826771735302141*^9, 
   3.8267717412558107`*^9}, {3.826772825520014*^9, 3.826772834856557*^9}, 
   3.826773064540346*^9, {3.8267731090732*^9, 3.826773197696018*^9}},
 CellLabel->
  "Out[258]=",ExpressionUUID->"bd67987c-82cb-44ea-8c82-6109095d50d4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "energies", " ", "denoted", " ", "by", " ", 
    RowBox[{"\"\<CMS\>\"", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"E1", "+", "E2"}], "//", "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E12", "+", "E3"}], "//", "Simplify"}]}]}]], "Input",
 CellChangeTimes->{{3.8267732640310593`*^9, 
  3.826773316722937*^9}},ExpressionUUID->"444d6458-a82a-4f46-bc06-\
c549fadba797"],

Cell[BoxData[
 FormBox[
  SqrtBox["s"], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826773266437162*^9, 3.826773300345644*^9}},
 CellLabel->
  "Out[265]=",ExpressionUUID->"e3272864-a7a5-413b-a4b8-32a7958907c0"],

Cell[BoxData[
 FormBox["M", TraditionalForm]], "Output",
 CellChangeTimes->{{3.826773266437162*^9, 3.8267733003503017`*^9}},
 CellLabel->
  "Out[266]=",ExpressionUUID->"77b9f80b-6383-4bc4-b2d4-4faea93d6ee7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Momentum", " ", "of", " ", "particle", " ", "3", " ", "in", " ", "the", 
    " ", "CMS", " ", "of", " ", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"1", ",", "2"}], ")"}], "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"Solve", "[", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["p", "2"], "+", 
       SuperscriptBox["M", "2"]}]], "\[Equal]", 
     RowBox[{"E1", "+", "E2", "+", 
      SqrtBox[
       RowBox[{
        SuperscriptBox["p", "2"], "+", 
        SuperscriptBox["m3", "2"]}]]}]}], ",", "p"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8267766675111094`*^9, 3.8267767282798758`*^9}, {
  3.8267767884857597`*^9, 
  3.82677681499219*^9}},ExpressionUUID->"ece9ebd0-8f13-4fa9-8f73-\
4daa7d20523c"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["M", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M", "2"], " ", 
           SuperscriptBox["m3", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M", "2"], " ", "s"}], "+", 
          SuperscriptBox["m3", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["m3", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", 
         SqrtBox["s"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["M", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M", "2"], " ", 
          SuperscriptBox["m3", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M", "2"], " ", "s"}], "+", 
         SuperscriptBox["m3", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["m3", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.8267768077184067`*^9},
 CellLabel->
  "Out[267]=",ExpressionUUID->"1bfb7155-22ad-459d-b8ab-c902a9b3c670"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "momentum", " ", "and", " ", "energy", " ", "found", " ", 
    RowBox[{"above", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"p3B", "=", 
    RowBox[{
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["M", "2"], ",", 
         SuperscriptBox["m3", "2"]}], "]"}]], 
      RowBox[{"2", 
       SqrtBox["s"]}]], "//", "Simplify"}]}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Note", " ", "that", " ", "we", " ", "have", " ", "to", " ", "include", 
     " ", "an", " ", "additional", " ", "minus", " ", "sign", " ", "here", 
     " ", "to", " ", "make", " ", "up", " ", "for", " ", "the", " ", "wrong", 
     " ", "sign", " ", "from", " ", "taking", " ", "the", " ", "square", " ", 
     "root", " ", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M", "2"], ">", 
        RowBox[{"s", "+", 
         SuperscriptBox["m3", "2"]}]}], ")"}], "."}]}], " ", "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{"E3B", "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         SqrtBox[
          RowBox[{
           SuperscriptBox["p3B", "2"], "+", 
           SuperscriptBox["m3", "2"]}]]}], "//", "Simplify"}], "//", 
       "PowerExpand"}], "//", "Expand"}], "//", "Simplify"}]}]}]}]], "Input",
 CellChangeTimes->{{3.826776823470582*^9, 
  3.826776993531682*^9}},ExpressionUUID->"bf834b4a-b0a2-40ac-b734-\
6598589c67fe"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox[
    RowBox[{
     SuperscriptBox["M", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["M", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m3", "2"], "+", "s"}], ")"}]}], "+", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["m3", "2"], "-", "s"}], ")"}], "2"]}]], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8267769016926823`*^9, 3.826776955012702*^9}},
 CellLabel->
  "Out[282]=",ExpressionUUID->"51b4082e-642c-40cb-83eb-7d01212fba47"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    SuperscriptBox["M", "2"], "-", 
    SuperscriptBox["m3", "2"], "-", "s"}], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8267769016926823`*^9, 3.826776955015644*^9}},
 CellLabel->
  "Out[283]=",ExpressionUUID->"7e8d3876-931c-4073-861d-23c73c563edb"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Find", " ", "the", " ", "relation", " ", "between", " ", "the", " ", 
    "differential", 
    RowBox[{"(", "s", ")"}], " ", "in", " ", "terms", " ", "of", " ", 
    SubscriptBox["d\[CapitalOmega]", "1"], 
    SubscriptBox["d\[CapitalOmega]", "3"], " ", "and", " ", 
    RowBox[{
     SubsuperscriptBox["dm", "23", "2"], "."}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"E2", "+", "E3B"}], ")"}], "2"], "-", 
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["p1", "2"], "+", 
       SuperscriptBox["p3B", "2"], "-", 
       RowBox[{"2", "p1", "*", "p3B", "*", 
        RowBox[{"Cos", "[", "\[Theta]", "]"}]}]}], ")"}]}], "//", 
    "PowerExpand"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.826779745234126*^9, 3.8267797998829327`*^9}, {
  3.826779842790176*^9, 3.826779860452942*^9}, {3.826780073278914*^9, 
  3.826780076097582*^9}, {3.82678022446037*^9, 3.8267802813895206`*^9}, {
  3.8267871249731073`*^9, 
  3.826787125377474*^9}},ExpressionUUID->"098c0f8f-bfd3-46f8-9a9f-\
5bde4db47087"],

Cell[BoxData[
 FormBox[
  FractionBox[
   RowBox[{
    RowBox[{
     SuperscriptBox["M", "2"], " ", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", 
        SuperscriptBox["m1", "2"]}], "+", 
       SuperscriptBox["m2", "2"], "+", "s"}], ")"}]}], "+", 
    RowBox[{
     RowBox[{"cos", "(", "\[Theta]", ")"}], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["M", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["M", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m3", "2"], "+", "s"}], ")"}]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m3", "2"], "-", "s"}], ")"}], "2"]}]], " ", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["m1", "4"], "-", 
       RowBox[{"2", " ", 
        SuperscriptBox["m1", "2"], " ", 
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m2", "2"], "+", "s"}], ")"}]}], "+", 
       SuperscriptBox[
        RowBox[{"(", 
         RowBox[{
          SuperscriptBox["m2", "2"], "-", "s"}], ")"}], "2"]}]]}], "+", 
    RowBox[{
     SuperscriptBox["m1", "2"], " ", 
     SuperscriptBox["m3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["m1", "2"], " ", "s"}], "-", 
    RowBox[{
     SuperscriptBox["m2", "2"], " ", 
     SuperscriptBox["m3", "2"]}], "+", 
    RowBox[{
     SuperscriptBox["m2", "2"], " ", "s"}], "+", 
    RowBox[{
     SuperscriptBox["m3", "2"], " ", "s"}], "-", 
    SuperscriptBox["s", "2"]}], 
   RowBox[{"2", " ", "s"}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.826779777514882*^9, 3.82677980019672*^9}, 
   3.8267798610381927`*^9, {3.82678007390716*^9, 3.826780077463004*^9}},
 CellLabel->
  "Out[289]=",ExpressionUUID->"3ff3d187-cf59-412f-8452-11760c7728a0"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1168, 694},
WindowMargins->{{Automatic, 42}, {Automatic, 0}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 217, 4, 97, "Title",ExpressionUUID->"bd5a5d2d-a113-4a65-94cb-ebcdc73c1261"],
Cell[CellGroupData[{
Cell[822, 30, 244, 4, 69, "Chapter",ExpressionUUID->"7463759e-6cfd-4cec-a3df-d3ec877f98fc"],
Cell[1069, 36, 1005, 29, 84, "Input",ExpressionUUID->"5c65b39f-f0a1-4376-8d8a-b8f9e3a6d008"],
Cell[2077, 67, 574, 16, 63, "Input",ExpressionUUID->"477d2a7a-0748-4af5-ac5c-8e442e5236c3"],
Cell[CellGroupData[{
Cell[2676, 87, 1402, 41, 129, "Input",ExpressionUUID->"a9b822e3-fb48-4c33-ac94-5ecb0ea797e7"],
Cell[4081, 130, 1387, 41, 69, "Output",ExpressionUUID->"0b17044b-088c-4bdb-98c5-a090cb5d55a5"],
Cell[5471, 173, 1348, 40, 65, "Output",ExpressionUUID->"89c0858b-f308-43ac-9627-cea5b0578a45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[6856, 218, 3859, 102, 500, "Input",ExpressionUUID->"c6a2b496-d952-4f3f-bb15-1ec509a75202"],
Cell[10718, 322, 970, 24, 84, "Output",ExpressionUUID->"a965b5e6-838b-4b63-8d2c-db41302dbda3"],
Cell[11691, 348, 720, 15, 64, "Output",ExpressionUUID->"cb2277a8-fb99-4af2-a625-a330cbe164ea"],
Cell[12414, 365, 954, 23, 80, "Output",ExpressionUUID->"c697b383-8e66-4030-82d4-534fd1608fcb"],
Cell[13371, 390, 703, 14, 60, "Output",ExpressionUUID->"2649d20e-9e19-4d42-b4ac-510e626f3470"],
Cell[14077, 406, 739, 16, 64, "Output",ExpressionUUID->"553f010c-8e7b-4278-a743-a5931a1e34eb"],
Cell[14819, 424, 703, 14, 60, "Output",ExpressionUUID->"bd67987c-82cb-44ea-8c82-6109095d50d4"]
}, Open  ]],
Cell[CellGroupData[{
Cell[15559, 443, 490, 12, 84, "Input",ExpressionUUID->"444d6458-a82a-4f46-bc06-c549fadba797"],
Cell[16052, 457, 217, 5, 48, "Output",ExpressionUUID->"e3272864-a7a5-413b-a4b8-32a7958907c0"],
Cell[16272, 464, 207, 4, 37, "Output",ExpressionUUID->"77b9f80b-6383-4bc4-b2d4-4faea93d6ee7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[16516, 473, 813, 25, 74, "Input",ExpressionUUID->"ece9ebd0-8f13-4fa9-8f73-4daa7d20523c"],
Cell[17332, 500, 1383, 41, 69, "Output",ExpressionUUID->"1bfb7155-22ad-459d-b8ab-c902a9b3c670"]
}, Open  ]],
Cell[CellGroupData[{
Cell[18752, 546, 1585, 45, 194, "Input",ExpressionUUID->"bf834b4a-b0a2-40ac-b734-6598589c67fe"],
Cell[20340, 593, 604, 19, 84, "Output",ExpressionUUID->"51b4082e-642c-40cb-83eb-7d01212fba47"],
Cell[20947, 614, 353, 10, 64, "Output",ExpressionUUID->"7e8d3876-931c-4073-861d-23c73c563edb"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21337, 629, 1165, 30, 66, "Input",ExpressionUUID->"098c0f8f-bfd3-46f8-9a9f-5bde4db47087"],
Cell[22505, 661, 1753, 54, 81, "Output",ExpressionUUID->"3ff3d187-cf59-412f-8452-11760c7728a0"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

